@@ -13,6 +13,8 @@ sub options {
 
 
 require Vimana::VimOnline;
+require Vimana::VimOnline::Search;
+require Vimana::VimOnline::ScriptPage;
 
 sub fetch_index {
     return Vimana::VimOnline::Search->fetch(
