@@ -3,9 +3,10 @@ use warnings;
 use strict;
 
 use Cache::File;
+use Moose;
 use Storable;
-use base qw(Class::Accessor::Fast);
-__PACKAGE__->mk_accessors( qw(cache) );
+
+has cache => ( is => 'rw' , isa => 'Cache::File' );
 
 sub init {
     my $self = shift;
